@@ -13,7 +13,7 @@ package Device::I2C::ADV7611;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -54,7 +54,7 @@ sub resetDevice {
     `echo 0 > /proc/v2r_gpio/99`;
     `echo 1 > /proc/v2r_gpio/99`;
     `echo 0 > /proc/v2r_gpio/pwctr2`;
-    sleep(0.5);
+    sleep(1);
     `echo 1 > /proc/v2r_gpio/pwctr2`;
 }
 
@@ -243,6 +243,11 @@ sub isLockTMDS {
     return $io->readIO(0x6a) & 0x43 == 0x43;
 }
 
+sub isInterlaced {
+    my ($io) = @_;
+    return $io->readIO(0x12) & 0x10;
+}
+
 sub isSignal {
     my ($io) = @_;
     my $res;
@@ -252,11 +257,6 @@ sub isSignal {
     $res &&= $io->isLockTMDS();
 }
 
-sub noLockCP {
-    my ($io) = @_;
-    return $io->readIO(0x12) & 0x01;
-}
-
 sub isFreeRun {
     my ($io) = @_;
     return $io->readCP(0xff) & 0x10;
@@ -309,6 +309,13 @@ sub getFPS1000 {
     return 28636360 / 256 / $fps * 1000;
 }
 
+sub getTMDSFreq {
+    my ($io) = @_;
+    my $freq = $io->readHDMI16(0x51);
+    my $frac = ( $freq & 0x7f ) / 128;
+    return ( $freq >> 7 ) + $frac;
+}
+
 1;
 
 __END__
@@ -326,8 +333,8 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611.svg?branch=build/master" alt="Travis status" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.09"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.09" alt="CPAN Testers result" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.09"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.09" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.10"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.10" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.10"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.10" alt="Distribution kwalitee" /></a>
 <a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
 </p>
 
@@ -335,7 +342,7 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
